@@ -76,10 +76,27 @@ class RouterProcess:
         self.thread = Thread(target=self.__process__)
         self.thread.daemon = True
         self.thread.start()
+        self.incoming_messages_threads = []
         while not self.running:
             pass
         RouterProcess.__handler = self
 
+    @staticmethod
+    def __incoming_message(connection, router, message):
+        message._source = connection
+        responses = router.route(message)
+        if responses:
+            for response in responses:
+                if isinstance(response, Message):
+                    connection.send(response)
+                elif isinstance(response, bool):
+                    response_message = Message(message.header + "_response", "success" if response else "fail")
+                    connection.send(response_message)
+                else:
+                    if response:
+                        response_message = Message(message.header + "_response", str(response))
+                        connection.send(response_message)
+
     def __process__(self):
         self.running = True
         while self.running:
@@ -89,19 +106,9 @@ class RouterProcess:
                     if connection.state == Connection.State.Open:
                         message = connection.receive()
                         if message:
-                            message._source = connection
-                            responses = router.route(message)
-                            if responses:
-                                for response in responses:
-                                    if isinstance(response, Message):
-                                        connection.send(response)
-                                    elif isinstance(response, bool):
-                                        response_message = Message(message.header + "_response", "success" if response else "fail")
-                                        connection.send(response_message)
-                                    else:
-                                        if response:
-                                            response_message = Message(message.header + "_response", str(response))
-                                            connection.send(response_message)
+                            new_thread = Thread(target=RouterProcess.__incoming_message, args=(connection, router, message))
+                            new_thread.start()
+                            self.incoming_messages_threads.append(new_thread)
                     else:
                         clean_up_required.append(index)
                 except:
@@ -118,3 +125,11 @@ class RouterProcess:
                     RouterProcess.__handler = None
                     self.running = False
                 RouterProcess.__mutex.release()
+
+            to_remove = []
+            while len(self.incoming_messages_threads) >= 10:
+                for t in self.incoming_messages_threads:
+                    if not t.is_alive():
+                        to_remove.append(t)
+                for t in to_remove:
+                    self.incoming_messages_threads.remove(t)
